@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminUser;
@@ -37,7 +37,8 @@ sub Run {
     my $MainObject      = $Kernel::OM->Get('Kernel::System::Main');
     my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
 
-    my $Search = $ParamObject->GetParam( Param => 'Search' ) || '';
+    my $Search       = $ParamObject->GetParam( Param => 'Search' )       || '';
+    my $Notification = $ParamObject->GetParam( Param => 'Notification' ) || '';
 
     # Get list of valid IDs.
     my @ValidIDList = $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet();
@@ -54,35 +55,15 @@ sub Run {
         # challenge token check for write action
         $LayoutObject->ChallengeTokenCheck();
 
-        my $UserID   = $ParamObject->GetParam( Param => 'UserID' ) || '';
+        my $UserID = $ParamObject->GetParam( Param => 'UserID' ) || '';
         my %UserData = $UserObject->GetUserData(
             UserID        => $UserID,
             NoOutOfOffice => 1,
         );
 
-        # get group object
-        my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
-
-        # get groups rw
-        my %GroupData = $GroupObject->PermissionUserGet(
-            UserID => $UserData{UserID},
-            Type   => 'rw',
-        );
-        for my $GroupKey ( sort keys %GroupData ) {
-            $UserData{"UserIsGroup[$GroupData{$GroupKey}]"} = 'Yes';
-        }
-
-        # get groups ro
-        %GroupData = $GroupObject->PermissionUserGet(
-            UserID => $UserData{UserID},
-            Type   => 'ro',
-        );
-        for my $GroupKey ( sort keys %GroupData ) {
-            $UserData{"UserIsGroupRo[$GroupData{$GroupKey}]"} = 'Yes';
-        }
         my $NewSessionID = $Kernel::OM->Get('Kernel::System::AuthSession')->CreateSessionID(
             %UserData,
-            UserLastRequest => $Kernel::OM->Get('Kernel::System::Time')->SystemTime(),
+            UserLastRequest => $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch(),
             UserType        => 'User',
             SessionSource   => 'AgentInterface',
         );
@@ -115,7 +96,7 @@ sub Run {
                 },
                 SessionID   => $NewSessionID,
                 SessionName => $ConfigObject->Get('SessionName'),
-            }
+                }
         );
 
         $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
@@ -144,6 +125,9 @@ sub Run {
         );
         my $Output = $LayoutObject->Header();
         $Output .= $LayoutObject->NavigationBar();
+        $Output .= $LayoutObject->Notify( Info => Translatable('Agent updated!') )
+            if ( $Notification && $Notification eq 'Update' );
+
         $Self->_Edit(
             Action => 'Change',
             Search => $Search,
@@ -198,7 +182,7 @@ sub Run {
             UserID    => $GetParam{UserID}
         );
         if ($UserLoginExists) {
-            $Errors{UserLoginExists}    = 1;
+            $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
         }
 
@@ -263,16 +247,22 @@ sub Run {
                 }
 
                 if ( !$Note ) {
-                    $Self->_Overview( Search => $Search );
-                    my $Output = $LayoutObject->Header();
-                    $Output .= $LayoutObject->NavigationBar();
-                    $Output .= $LayoutObject->Notify( Info => Translatable('Agent updated!') );
-                    $Output .= $LayoutObject->Output(
-                        TemplateFile => 'AdminUser',
-                        Data         => \%Param,
-                    );
-                    $Output .= $LayoutObject->Footer();
-                    return $Output;
+
+                    # if the user would like to continue editing the agent, just redirect to the edit screen
+                    # otherwise return to overview
+                    if (
+                        defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
+                        && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
+                        )
+                    {
+                        my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
+                        return $LayoutObject->Redirect(
+                            OP => "Action=$Self->{Action};Subaction=Change;UserID=$GetParam{UserID};Notification=Update"
+                        );
+                    }
+                    else {
+                        return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Notification=Update" );
+                    }
                 }
             }
             else {
@@ -362,7 +352,7 @@ sub Run {
         # check if a user with this login (username) already exits
         my $UserLoginExists = $UserObject->UserLoginExistsCheck( UserLogin => $GetParam{UserLogin} );
         if ($UserLoginExists) {
-            $Errors{UserLoginExists}    = 1;
+            $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
         }
 
@@ -484,6 +474,9 @@ sub Run {
         $Self->_Overview( Search => $Search );
         my $Output = $LayoutObject->Header();
         $Output .= $LayoutObject->NavigationBar();
+        $Output .= $LayoutObject->Notify( Info => Translatable('Agent updated!') )
+            if ( $Notification && $Notification eq 'Update' );
+
         $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminUser',
             Data         => \%Param,
@@ -506,6 +499,31 @@ sub _Edit {
     $LayoutObject->Block( Name => 'ActionList' );
     $LayoutObject->Block( Name => 'ActionOverview' );
 
+    # check if the current user has the permissions to edit another users preferences
+    if ( $Param{Action} eq 'Change' ) {
+
+        my $GroupObject                      = $Kernel::OM->Get('Kernel::System::Group');
+        my $EditAnotherUsersPreferencesGroup = $GroupObject->GroupLookup(
+            Group => $Kernel::OM->Get('Kernel::Config')->Get('EditAnotherUsersPreferencesGroup'),
+        );
+
+        # get user groups, where the user has the rw privilege
+        my %Groups = $GroupObject->PermissionUserGet(
+            UserID => $Self->{UserID},
+            Type   => 'rw',
+        );
+
+        # if the user is a member in this group he can access the feature
+        if ( $Groups{$EditAnotherUsersPreferencesGroup} ) {
+            $LayoutObject->Block(
+                Name => 'ActionEditPreferences',
+                Data => {
+                    UserID => $Param{UserID},
+                },
+            );
+        }
+    }
+
     # get valid list
     my %ValidList        = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
     my %ValidListReverse = reverse %ValidList;
@@ -522,16 +540,20 @@ sub _Edit {
         Data => \%Param,
     );
 
-    # shows header
     if ( $Param{Action} eq 'Change' ) {
+
+        # shows edit header
         $LayoutObject->Block( Name => 'HeaderEdit' );
+
+        # shows effective permissions matrix
+        $Self->_EffectivePermissions(%Param);
     }
     else {
+
+        # shows add header and hints
         $LayoutObject->Block( Name => 'HeaderAdd' );
         $LayoutObject->Block( Name => 'MarkerMandatory' );
-        $LayoutObject->Block(
-            Name => 'ShowPasswordHint',
-        );
+        $LayoutObject->Block( Name => 'ShowPasswordHint' );
     }
 
     # add the correct server error message
@@ -558,98 +580,6 @@ sub _Edit {
         $LayoutObject->Block( Name => 'UserLoginServerError' );
     }
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
-    my @Groups = @{ $ConfigObject->Get('PreferencesView') };
-    for my $Column (@Groups) {
-        my %Data        = ();
-        my %Preferences = %{ $ConfigObject->Get('PreferencesGroups') };
-
-        GROUP:
-        for my $Group ( sort keys %Preferences ) {
-            next GROUP if $Preferences{$Group}->{Column} ne $Column;
-
-            if ( $Data{ $Preferences{$Group}->{Prio} } ) {
-                COUNT:
-                for ( 1 .. 151 ) {
-                    $Preferences{$Group}->{Prio}++;
-                    if ( !$Data{ $Preferences{$Group}->{Prio} } ) {
-                        $Data{ $Preferences{$Group}->{Prio} } = $Group;
-                        last COUNT;
-                    }
-                }
-            }
-            $Data{ $Preferences{$Group}->{Prio} } = $Group;
-        }
-
-        # sort
-        for my $Key ( sort keys %Data ) {
-            $Data{ sprintf( "%07d", $Key ) } = $Data{$Key};
-            delete $Data{$Key};
-        }
-
-        # show each preferences setting
-        PRIO:
-        for my $Prio ( sort keys %Data ) {
-            my $Group = $Data{$Prio};
-            if ( !$ConfigObject->{PreferencesGroups}->{$Group} ) {
-                next PRIO;
-            }
-            my %Preference = %{ $ConfigObject->{PreferencesGroups}->{$Group} };
-            if ( $Group eq 'Password' ) {
-                next PRIO;
-            }
-            my $Module = $Preference{Module} || 'Kernel::Output::HTML::Preferences::Generic';
-
-            # load module
-            if ( $Kernel::OM->Get('Kernel::System::Main')->Require($Module) ) {
-
-                # TODO: This needs to be changed to Object Manager
-                my $Object = $Module->new(
-                    %{$Self},
-                    UserObject => $Kernel::OM->Get('Kernel::System::User'),
-                    ConfigItem => \%Preference,
-                    Debug      => $Self->{Debug},
-                );
-                my @Params = $Object->Param( UserData => \%Param );
-                if (@Params) {
-                    for my $ParamItem (@Params) {
-                        $LayoutObject->Block(
-                            Name => 'Item',
-                            Data => { %Param, },
-                        );
-                        if (
-                            ref( $ParamItem->{Data} ) eq 'HASH'
-                            || ref( $Preference{Data} ) eq 'HASH'
-                            )
-                        {
-                            my %BuildSelectionParams = (
-                                %Preference,
-                                %{$ParamItem},
-                            );
-                            $BuildSelectionParams{Class} = join( ' ', $BuildSelectionParams{Class} // '', 'Modernize' );
-
-                            $ParamItem->{'Option'} = $LayoutObject->BuildSelection(
-                                %BuildSelectionParams,
-                            );
-                        }
-                        $LayoutObject->Block(
-                            Name => $ParamItem->{Block} || $Preference{Block} || 'Option',
-                            Data => {
-                                Group => $Group,
-                                %Preference,
-                                %{$ParamItem},
-                            },
-                        );
-                    }
-                }
-            }
-            else {
-                return $LayoutObject->FatalError();
-            }
-        }
-    }
     return 1;
 }
 
@@ -685,34 +615,36 @@ sub _Overview {
         Limit  => $Limit,
         Valid  => 0,
     );
-    my %ListAll = $UserObject->UserSearch(
+
+    my %ListAllItems = $UserObject->UserSearch(
         Search => $Param{Search} . '*',
         Limit  => $Limit + 1,
         Valid  => 0,
     );
 
-    if ( keys %ListAll <= $Limit ) {
-        my $ListAll = keys %ListAll;
+    if ( keys %ListAllItems <= $Limit ) {
+        my $ListAllItems = keys %ListAllItems;
         $LayoutObject->Block(
             Name => 'OverviewHeader',
             Data => {
-                ListAll => $ListAll,
+                ListAll => $ListAllItems,
                 Limit   => $Limit,
             },
         );
     }
     else {
-        my $ListAll        = keys %ListAll;
+        my $ListAllSize    = keys %ListAllItems;
         my $SearchListSize = keys %List;
 
         $LayoutObject->Block(
             Name => 'OverviewHeader',
             Data => {
                 SearchListSize => $SearchListSize,
-                ListAll        => $ListAll,
+                ListAll        => $ListAllSize,
                 Limit          => $Limit,
             },
         );
+
     }
 
     $LayoutObject->Block(
@@ -773,4 +705,81 @@ sub _Overview {
     return 1;
 }
 
+sub _EffectivePermissions {
+    my ( $Self, %Param ) = @_;
+
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    # show tables
+    $LayoutObject->Block(
+        Name => 'EffectivePermissions',
+    );
+
+    my %Groups;
+    my %Permissions;
+
+    # go through permission types
+    my @Types = @{ $Kernel::OM->Get('Kernel::Config')->Get('System::Permission') };
+    for my $Type (@Types) {
+
+        # show header
+        $LayoutObject->Block(
+            Name => 'HeaderGroupPermissionType',
+            Data => {
+                Type => $Type,
+            },
+        );
+
+        # get groups of the user
+        my %UserGroups = $Kernel::OM->Get('Kernel::System::Group')->PermissionUserGet(
+            UserID => $Param{UserID},
+            Type   => $Type,
+        );
+
+        # store data in lookup hashes
+        for my $GroupID ( sort keys %UserGroups ) {
+            $Groups{$GroupID} = $UserGroups{$GroupID};
+            $Permissions{$GroupID}{$Type} = 1;
+        }
+    }
+
+    # show message if no permissions found
+    if ( !%Permissions ) {
+        $LayoutObject->Block(
+            Name => 'NoGroupPermissionsFoundMsg',
+        );
+        return;
+    }
+
+    # go through groups, sort by name
+    for my $GroupID ( sort { uc( $Groups{$a} ) cmp uc( $Groups{$b} ) } keys %Groups ) {
+
+        # show table rows
+        $LayoutObject->Block(
+            Name => 'GroupPermissionTableRow',
+            Data => {
+                ID   => $GroupID,
+                Name => $Groups{$GroupID},
+            },
+        );
+
+        # show permission marks
+        for my $Type (@Types) {
+            my $PermissionMark = $Permissions{$GroupID}{$Type} ? 'On' : 'Off';
+            my $HighlightMark = $Type eq 'rw' ? 'Highlight' : '';
+            $LayoutObject->Block(
+                Name => 'GroupPermissionMark',
+            );
+            $LayoutObject->Block(
+                Name => 'GroupPermissionMark' . $PermissionMark,
+                Data => {
+                    Highlight => $HighlightMark,
+                },
+            );
+        }
+    }
+    return;
+}
+
 1;
