@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,7 +11,7 @@ package Kernel::Output::Template::Plugin::OTRS;
 use strict;
 use warnings;
 
-use base qw(Template::Plugin);
+use parent qw(Template::Plugin);
 
 use Scalar::Util;
 
@@ -23,11 +23,7 @@ Kernel::Output::Template::Plugin::OTRS - Template Toolkit extension plugin
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 this plugin registers a few filters and functions in Template::Toolkit.
 
@@ -37,23 +33,27 @@ are always lowercase.
 
 Filters:
 
-    [% Data.MyData  | Translate %]              - Translate to user language.
+    [% Data.MyData  | Translate %]                         - Translate to user language.
 
-    [% Data.Created | Localize("TimeLong") %]   - Format DateTime string according to user's locale.
-    [% Data.Created | Localize("TimeShort") %]  - Format DateTime string according to user's locale, without seconds.
-    [% Data.Created | Localize("Date") %]       - Format DateTime string according to user's locale, only date.
+    [% Data.Created | Localize("TimeLong") %]              - Format DateTime string according to user's locale.
+    [% Data.Created | Localize("TimeShort") %]             - Format DateTime string according to user's locale, without seconds.
+    [% Data.Created | Localize("Date") %]                  - Format DateTime string according to user's locale, only date.
 
-    [% Data.Complex | Interpolate %]            - Treat Data.Complex as a TT template and parse it.
+    [% Data.Complex | Interpolate %]                       - Treat Data.Complex as a TT template and parse it.
 
-    [% Data.Complex | JSON %]                   - Convert Data.Complex into a JSON string.
+    [% Data.String  | ReplacePlaceholders("one", "two") %] - Replace Data.String placeholders (i.e. %s) with supplied strings.
+
+    [% Data.Complex | JSON %]                              - Convert Data.Complex into a JSON string.
 
 Functions:
 
-    [% Translate("Test string for %s", "Documentation") %]  - Translate text, with placeholders.
+    [% Translate("Test string for %s", "Documentation") %]                - Translate text, with placeholders.
 
-    [% Config("Home") %]    - Get SysConfig configuration value.
+    [% Config("Home") %]                                                  - Get SysConfig configuration value.
 
-    [% Env("Baselink") %]   - Get environment value of LayoutObject.
+    [% Env("Baselink") %]                                                 - Get environment value of LayoutObject.
+
+    [% ReplacePlaceholders("This is %s", "<strong>bold text</strong>") %] - Replace string placeholders with supplied values.
 
 =cut
 
@@ -98,6 +98,9 @@ sub new {
         elsif ( $Format eq 'Date' ) {
             return $LayoutObject->{LanguageObject}->FormatTimeString( $_[0], 'DateFormatShort' );
         }
+        elsif ( $Format eq 'Filesize' ) {
+            return $LayoutObject->HumanReadableDataSize( Size => $_[0] );
+        }
         return;
     };
 
@@ -115,6 +118,9 @@ sub new {
             elsif ( $Format eq 'Date' ) {
                 return $LayoutObject->{LanguageObject}->FormatTimeString( $_[0], 'DateFormatShort' );
             }
+            elsif ( $Format eq 'Filesize' ) {
+                return $LayoutObject->HumanReadableDataSize( Size => $_[0] );
+            }
             return;
         };
     };
@@ -142,6 +148,29 @@ sub new {
         };
     };
 
+    # This filter replaces any placeholder occurrences in first parameter (i.e. %s or %d), with following parameters.
+    my $ReplacePlaceholdersFunction = sub {
+        my ( $Text, @Parameters ) = @_;
+
+        $Text //= '';
+
+        return $Text if !@Parameters;
+
+        for ( 0 .. $#Parameters ) {
+            return $Text if !defined $Parameters[$_];
+            $Text =~ s/%(s|d)/$Parameters[$_]/;
+        }
+
+        return $Text;
+    };
+
+    my $ReplacePlaceholdersFilter = sub {
+        my ( $FilterContext, @Parameters ) = @_;
+        return sub {
+            return $ReplacePlaceholdersFunction->( $_[0], @Parameters );
+        };
+    };
+
     my $JSONFunction = sub {
         return $LayoutObject->JSONEncode( Data => $_[0] );
     };
@@ -150,16 +179,18 @@ sub new {
         return $LayoutObject->JSONEncode( Data => $_[0] );
     };
 
-    $Context->stash()->set( 'Config',      $ConfigFunction );
-    $Context->stash()->set( 'Env',         $EnvFunction );
-    $Context->stash()->set( 'Translate',   $TranslateFunction );
-    $Context->stash()->set( 'Localize',    $LocalizeFunction );
-    $Context->stash()->set( 'Interpolate', $InterpolateFunction );
-    $Context->stash()->set( 'JSON',        $JSONFunction );
+    $Context->stash()->set( 'Config',              $ConfigFunction );
+    $Context->stash()->set( 'Env',                 $EnvFunction );
+    $Context->stash()->set( 'Translate',           $TranslateFunction );
+    $Context->stash()->set( 'Localize',            $LocalizeFunction );
+    $Context->stash()->set( 'Interpolate',         $InterpolateFunction );
+    $Context->stash()->set( 'ReplacePlaceholders', $ReplacePlaceholdersFunction );
+    $Context->stash()->set( 'JSON',                $JSONFunction );
 
-    $Context->define_filter( 'Translate',   [ $TranslateFilterFactory,   1 ] );
-    $Context->define_filter( 'Localize',    [ $LocalizeFilterFactory,    1 ] );
-    $Context->define_filter( 'Interpolate', [ $InterpolateFilterFactory, 1 ] );
+    $Context->define_filter( 'Translate',           [ $TranslateFilterFactory,    1 ] );
+    $Context->define_filter( 'Localize',            [ $LocalizeFilterFactory,     1 ] );
+    $Context->define_filter( 'Interpolate',         [ $InterpolateFilterFactory,  1 ] );
+    $Context->define_filter( 'ReplacePlaceholders', [ $ReplacePlaceholdersFilter, 1 ] );
     $Context->define_filter( 'JSON', $JSONFilter );
 
     return bless {
@@ -168,8 +199,6 @@ sub new {
     }, $Class;
 }
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (L<http://otrs.org/>).
