@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::CSV;
@@ -22,20 +22,16 @@ our @ObjectDependencies = (
 
 Kernel::System::CSV - CSV lib
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All csv functions.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
+=head2 new()
 
-=item new()
+Don't use the constructor directly, use the ObjectManager instead:
 
-create an object. Do not use it directly, instead use:
-
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $CSVObject = $Kernel::OM->Get('Kernel::System::CSV');
 
 =cut
@@ -50,7 +46,7 @@ sub new {
     return $Self;
 }
 
-=item Array2CSV()
+=head2 Array2CSV()
 
 Returns a csv formatted string based on a array with head data.
 
@@ -226,7 +222,7 @@ sub Array2CSV {
     return $Output;
 }
 
-=item CSV2Array()
+=head2 CSV2Array()
 
 Returns an array with parsed csv data.
 
@@ -245,10 +241,10 @@ sub CSV2Array {
     my $CSV = Text::CSV->new(
         {
 
-            quote_char          => $Param{Quote} // '"',
-            escape_char         => $Param{Quote} || '"',
-            sep_char            => $Param{Separator} || ";",
-            eol                 => '',
+            quote_char => $Param{Quote} // '"',
+            escape_char => $Param{Quote}     || '"',
+            sep_char    => $Param{Separator} || ";",
+            eol         => '',
             always_quote        => 0,
             binary              => 1,
             keep_meta_info      => 0,
@@ -288,14 +284,12 @@ sub CSV2Array {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
