@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 use utf8;
 
-use base qw(Kernel::System::Daemon::BaseDaemon);
+use parent qw(Kernel::System::Daemon::BaseDaemon);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -20,24 +20,19 @@ our @ObjectDependencies = (
     'Kernel::System::Daemon::SchedulerDB',
     'Kernel::System::Cache',
     'Kernel::System::Log',
-    'Kernel::System::Time',
 );
 
 =head1 NAME
 
 Kernel::System::Daemon::DaemonModules::SchedulerFutureTaskManager - daemon to manage scheduler future tasks
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Scheduler future task daemon
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 Create scheduler future task manager object.
 
@@ -76,7 +71,7 @@ sub new {
 
     # Do not change the following values!
     # Modulo in PreRun() can be damaged after a change.
-    $Self->{SleepPost} = 1;          # sleep 60 seconds after each loop
+    $Self->{SleepPost} = 1;          # sleep 1 second after each loop
     $Self->{Discard}   = 60 * 60;    # discard every hour
 
     $Self->{DiscardCount} = $Self->{Discard} / $Self->{SleepPost};
@@ -119,8 +114,8 @@ sub PostRun {
 
     $Self->{DiscardCount}--;
 
-    if ( $Self->{Debug} ) {
-        print "  $Self->{DaemonName} Discard Count: $Self->{DiscardCount}\n";
+    if ( $Self->{Debug} && $Self->{DiscardCount} == 0 ) {
+        print "  $Self->{DaemonName} will be stopped and set for restart!\n";
     }
 
     return if $Self->{DiscardCount} <= 0;
@@ -141,8 +136,6 @@ sub DESTROY {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (L<http://otrs.org/>).
