@@ -39,6 +39,8 @@ our @ObjectDependencies = (
     'Kernel::System::Log',
 );
 
+our $Locale = DateTime::Locale->load('en_US');
+
 use overload
     '>'        => \&_OpIsNewerThan,
     '<'        => \&_OpIsOlderThan,
@@ -74,7 +76,7 @@ Creates a DateTime object. Do not use new() directly, instead use the object man
     my $DateTimeObject = $Kernel::OM->Create(
         'Kernel::System::DateTime',
         ObjectParams => {
-            TimeZone => 'Europe/Berlin',        # optional
+            TimeZone => 'Europe/Berlin',        # optional, TimeZone name.
         }
     );
 
@@ -125,7 +127,7 @@ sub new {
 
     # CPAN DateTime: only use English descriptions and abbreviations internally.
     #   This has nothing to do with the user's locale settings in OTRS.
-    $Self->{Locale} = 'en_US';
+    $Self->{Locale} = $Locale;
 
     # Use private parameter to pass in an already created CPANDateTimeObject (used)
     #   by the Clone() method).
@@ -136,7 +138,8 @@ sub new {
 
     # Create the CPAN/Perl DateTime object.
     my $CPANDateTimeObject = $Self->_CPANDateTimeObjectCreate(%Param);
-    if ( !$CPANDateTimeObject ) {
+
+    if ( ref $CPANDateTimeObject ne 'DateTime' ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             'Priority' => 'Error',
             'Message'  => 'Error creating DateTime object.',
