@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Group;
@@ -24,22 +24,16 @@ our @ObjectDependencies = (
 
 Kernel::System::Group - group and roles lib
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All group and roles functions. E. g. to add groups or to get a member list of a group.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
+=head2 new()
 
-=cut
+Don't use the constructor directly, use the ObjectManager instead:
 
-=item new()
-
-create an object. Do not use it directly, instead use:
-
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
 
 =cut
@@ -54,7 +48,7 @@ sub new {
     return $Self;
 }
 
-=item GroupLookup()
+=head2 GroupLookup()
 
 get id or name for group
 
@@ -93,7 +87,7 @@ sub GroupLookup {
     return $GroupListReverse{ $Param{Group} };
 }
 
-=item GroupAdd()
+=head2 GroupAdd()
 
 to add a group
 
@@ -124,7 +118,7 @@ sub GroupAdd {
     if ( defined $ExistingGroups{ $Param{Name} } ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A Group with the name $Param{Name} already exists.",
+            Message  => "A group with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -176,7 +170,7 @@ sub GroupAdd {
     return $GroupID;
 }
 
-=item GroupGet()
+=head2 GroupGet()
 
 returns a hash with group data
 
@@ -223,7 +217,7 @@ sub GroupGet {
     return %Group;
 }
 
-=item GroupUpdate()
+=head2 GroupUpdate()
 
 update of a group
 
@@ -255,7 +249,7 @@ sub GroupUpdate {
     if ( defined $ExistingGroups{ $Param{Name} } && $ExistingGroups{ $Param{Name} } != $Param{ID} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A Group with the name $Param{Name} already exists.",
+            Message  => "A group with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -326,7 +320,7 @@ sub GroupUpdate {
     return 1;
 }
 
-=item GroupList()
+=head2 GroupList()
 
 returns a hash of all groups
 
@@ -415,7 +409,7 @@ sub GroupList {
     return %GroupListAll;
 }
 
-=item GroupDataList()
+=head2 GroupDataList()
 
 returns a hash of all group data
 
@@ -496,7 +490,7 @@ sub GroupDataList {
     return %GroupDataList;
 }
 
-=item RoleLookup()
+=head2 RoleLookup()
 
 get id or name for role
 
@@ -535,7 +529,7 @@ sub RoleLookup {
     return $RoleListReverse{ $Param{Role} };
 }
 
-=item RoleGet()
+=head2 RoleGet()
 
 returns a hash with role data
 
@@ -582,7 +576,7 @@ sub RoleGet {
     return %Role;
 }
 
-=item RoleAdd()
+=head2 RoleAdd()
 
 to add a new role
 
@@ -613,7 +607,7 @@ sub RoleAdd {
     if ( defined $ExistingRoles{ $Param{Name} } ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A Role with the name $Param{Name} already exists.",
+            Message  => "A role with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -663,7 +657,7 @@ sub RoleAdd {
     return $RoleID;
 }
 
-=item RoleUpdate()
+=head2 RoleUpdate()
 
 update of a role
 
@@ -695,7 +689,7 @@ sub RoleUpdate {
     if ( defined $ExistingRoles{ $Param{Name} } && $ExistingRoles{ $Param{Name} } != $Param{ID} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A Role with the name $Param{Name} already exists.",
+            Message  => "A role with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -760,7 +754,7 @@ sub RoleUpdate {
     return 1;
 }
 
-=item RoleList()
+=head2 RoleList()
 
 returns a hash of all roles
 
@@ -849,7 +843,7 @@ sub RoleList {
     return %RoleListAll;
 }
 
-=item RoleDataList()
+=head2 RoleDataList()
 
 returns a hash of all role data
 
@@ -930,13 +924,43 @@ sub RoleDataList {
     return %RoleDataList;
 }
 
-=item PermissionUserInvolvedGet()
+=head2 PermissionCheck()
+
+Check if a user has a certain permission for a certain group.
+
+    my $HasPermission = $GroupObject->PermissionCheck(
+        UserID    => $UserID,
+        GroupName => $GroupName,
+        Type      => 'move_into',
+    );
+
+=cut
+
+sub PermissionCheck {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for (qw(UserID GroupName Type)) {
+        if ( !$Param{$_} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!",
+            );
+            return;
+        }
+    }
+
+    # PermissionUserGet already has in-memory caching enabled, so don't cache again here.
+    return { reverse $Self->PermissionUserGet(%Param) }->{ $Param{GroupName} } ? 1 : 0;
+}
+
+=head2 PermissionUserInvolvedGet()
 
 returns a list of users with the given permissions
 
     my %Users = $GroupObject->PermissionUserInvolvedGet(
         UserID => $ID,
-        Type   => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type   => 'move_into',
     );
 
 =cut
@@ -976,13 +1000,13 @@ sub PermissionUserInvolvedGet {
     return %Users;
 }
 
-=item PermissionUserGet()
+=head2 PermissionUserGet()
 
 Get groups of the given user.
 
     my %Groups = $GroupObject->PermissionUserGet(
         UserID => $ID,
-        Type   => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type   => 'move_into',
     );
 
 =cut
@@ -1051,13 +1075,13 @@ sub PermissionUserGet {
     return %GroupList;
 }
 
-=item PermissionGroupGet()
+=head2 PermissionGroupGet()
 
 Get users of the given group.
 
     my %Users = $GroupObject->PermissionGroupGet(
         GroupID => $ID,
-        Type    => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type    => 'move_into',
     );
 
 =cut
@@ -1126,7 +1150,7 @@ sub PermissionGroupGet {
     return %UserList;
 }
 
-=item PermissionGroupUserAdd()
+=head2 PermissionGroupUserAdd()
 
 add new permissions or update existing one to the given group of a given user
 
@@ -1137,7 +1161,6 @@ add new permissions or update existing one to the given group of a given user
             ro        => 1,
             move_into => 1,
             create    => 1,
-            note      => 1,
             owner     => 1,
             priority  => 0,
             rw        => 0,
@@ -1226,19 +1249,16 @@ sub PermissionGroupUserAdd {
     TYPE:
     for my $Type (@NewPermissions) {
 
-        my $ValueNew = 1;
-
         # add to database
         $DBObject->Do(
             SQL => 'INSERT INTO group_user '
-                . '(user_id, group_id, permission_key, permission_value, '
+                . '(user_id, group_id, permission_key, '
                 . 'create_time, create_by, change_time, change_by) '
-                . 'VALUES (?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
+                . 'VALUES (?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
             Bind => [
                 \$Param{UID},
                 \$Param{GID},
                 \$Type,
-                \$ValueNew,
                 \$Param{UserID},
                 \$Param{UserID},
             ],
@@ -1263,13 +1283,13 @@ sub PermissionGroupUserAdd {
     return 1;
 }
 
-=item PermissionGroupUserGet()
+=head2 PermissionGroupUserGet()
 
 returns a list with all users of a group
 
     my %UserList = $GroupObject->PermissionGroupUserGet(
         GroupID => $GroupID,
-        Type    => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type    => 'move_into',  # ro|move_into|priority|create|rw
     );
 
     %UserList = (
@@ -1346,13 +1366,13 @@ sub PermissionGroupUserGet {
     return %Users;
 }
 
-=item PermissionUserGroupGet()
+=head2 PermissionUserGroupGet()
 
 returns a list of groups a user is member of
 
     my %GroupList = $GroupObject->PermissionUserGroupGet(
         UserID => 123,
-        Type   => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type   => 'move_into',  # ro|move_into|priority|create|rw
     );
 
     %GroupList = (
@@ -1428,7 +1448,7 @@ sub PermissionUserGroupGet {
     return %Groups;
 }
 
-=item PermissionGroupRoleAdd()
+=head2 PermissionGroupRoleAdd()
 
 add new permissions or update existing one to the given group of a given role
 
@@ -1439,7 +1459,6 @@ add new permissions or update existing one to the given group of a given role
             ro        => 1,
             move_into => 1,
             create    => 1,
-            note      => 1,
             owner     => 1,
             priority  => 0,
             rw        => 0,
@@ -1565,13 +1584,13 @@ sub PermissionGroupRoleAdd {
     return 1;
 }
 
-=item PermissionGroupRoleGet()
+=head2 PermissionGroupRoleGet()
 
 returns a list with all roles of a group
 
     my %RoleList = $GroupObject->PermissionGroupRoleGet(
         GroupID => $GroupID,
-        Type    => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type    => 'move_into',  # ro|move_into|priority|create|rw
     );
 
     %RoleList = (
@@ -1646,13 +1665,13 @@ sub PermissionGroupRoleGet {
     return %Roles;
 }
 
-=item PermissionRoleGroupGet()
+=head2 PermissionRoleGroupGet()
 
 returns a list with all groups of a role
 
     my %GroupList = $GroupObject->PermissionRoleGroupGet(
         RoleID => 12,
-        Type   => 'move_into',  # ro|move_into|create|note|owner|priority|rw
+        Type   => 'move_into',  # ro|move_into|priority|create|rw
     );
 
     %GroupList = (
@@ -1727,7 +1746,7 @@ sub PermissionRoleGroupGet {
     return %Groups;
 }
 
-=item PermissionRoleUserAdd()
+=head2 PermissionRoleUserAdd()
 
 add new permissions or update existing one to the given group of a given role
 
@@ -1798,7 +1817,7 @@ sub PermissionRoleUserAdd {
     return 1;
 }
 
-=item PermissionRoleUserGet()
+=head2 PermissionRoleUserGet()
 
 returns a list with all users of a role
 
@@ -1861,7 +1880,7 @@ sub PermissionRoleUserGet {
     return %Users;
 }
 
-=item PermissionUserRoleGet()
+=head2 PermissionUserRoleGet()
 
 returns a list with all roles of a user
 
@@ -1924,7 +1943,7 @@ sub PermissionUserRoleGet {
     return %Roles;
 }
 
-=item GroupMemberAdd()
+=head2 GroupMemberAdd()
 
 Function for backward compatibility. Redirected to PermissionGroupUserAdd().
 
@@ -1936,7 +1955,7 @@ sub GroupMemberAdd {
     return $Self->PermissionGroupUserAdd(%Param);
 }
 
-=item GroupMemberList()
+=head2 GroupMemberList()
 
 Function for backward compatibility. Redirected to PermissionUserGet() and PermissionGroupGet().
 
@@ -2015,7 +2034,7 @@ sub GroupMemberList {
     return;
 }
 
-=item GroupMemberInvolvedList()
+=head2 GroupMemberInvolvedList()
 
 Function for backward compatibility. Redirected to PermissionUserInvolvedGet().
 
@@ -2027,7 +2046,7 @@ sub GroupMemberInvolvedList {
     return $Self->PermissionUserInvolvedGet(%Param);
 }
 
-=item GroupGroupMemberList()
+=head2 GroupGroupMemberList()
 
 Function for backward compatibility. Redirected to PermissionUserGroupGet() and PermissionGroupUserGet().
 
@@ -2133,7 +2152,7 @@ sub GroupGroupMemberList {
     return;
 }
 
-=item GroupRoleMemberList()
+=head2 GroupRoleMemberList()
 
 Function for backward compatibility. Redirected to PermissionRoleGroupGet() and PermissionGroupRoleGet().
 
@@ -2239,7 +2258,7 @@ sub GroupRoleMemberList {
     return;
 }
 
-=item GroupRoleMemberAdd()
+=head2 GroupRoleMemberAdd()
 
 Function for backward compatibility. Redirected to PermissionGroupRoleAdd().
 
@@ -2251,7 +2270,7 @@ sub GroupRoleMemberAdd {
     return $Self->PermissionGroupRoleAdd(%Param);
 }
 
-=item GroupUserRoleMemberList()
+=head2 GroupUserRoleMemberList()
 
 Function for backward compatibility. Redirected to PermissionUserRoleGet() and PermissionRoleUserGet().
 
@@ -2354,7 +2373,7 @@ sub GroupUserRoleMemberList {
     return;
 }
 
-=item GroupUserRoleMemberAdd()
+=head2 GroupUserRoleMemberAdd()
 
 Function for backward compatibility. Redirected to PermissionRoleUserAdd().
 
@@ -2370,7 +2389,7 @@ sub GroupUserRoleMemberAdd {
 
 =cut
 
-=item _DBGroupUserGet()
+=head2 _DBGroupUserGet()
 
 returns the content of the database table group_user
 
@@ -2483,10 +2502,8 @@ sub _DBGroupUserGet {
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
     # get all data from table group_user
-    # We need to check for permission_value=1 because in previous OTRS 4 and below there could be records created
-    #   with 0 (see bug#11616).
     $DBObject->Prepare(
-        SQL => 'SELECT user_id, group_id, permission_key FROM group_user WHERE permission_value = 1',
+        SQL => 'SELECT user_id, group_id, permission_key FROM group_user',
     );
 
     # fetch the result
@@ -2529,7 +2546,7 @@ sub _DBGroupUserGet {
     return %GroupPermUserList;
 }
 
-=item _DBGroupRoleGet()
+=head2 _DBGroupRoleGet()
 
 returns the content of the database table group_role
 
@@ -2688,7 +2705,7 @@ sub _DBGroupRoleGet {
     return %GroupPermRoleList;
 }
 
-=item _DBRoleUserGet()
+=head2 _DBRoleUserGet()
 
 returns the content of the database table role_user
 
@@ -2834,7 +2851,7 @@ sub _DBRoleUserGet {
     return %UserRoleHash;
 }
 
-=item _PermissionTypeList()
+=head2 _PermissionTypeList()
 
 returns a list of valid system permissions.
 
@@ -2872,14 +2889,12 @@ sub _PermissionTypeList {
 
 =end Internal:
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
