@@ -26,22 +26,16 @@ our @ObjectDependencies = (
 
 Kernel::System::ProcessManagement::DB::Activity
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Process Management DB Activity backend
 
 =head1 PUBLIC INTERFACE
 
-=over 4
+=head2 new()
 
-=cut
+Don't use the constructor directly, use the ObjectManager instead:
 
-=item new()
-
-create an object. Do not use it directly, instead use:
-
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $ActivityObject = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Activity');
 
 =cut
@@ -65,7 +59,7 @@ sub new {
     return $Self;
 }
 
-=item ActivityAdd()
+=head2 ActivityAdd()
 
 add new Activity
 
@@ -172,7 +166,7 @@ sub ActivityAdd {
     return $ID;
 }
 
-=item ActivityDelete()
+=head2 ActivityDelete()
 
 delete an Activity
 
@@ -220,7 +214,7 @@ sub ActivityDelete {
     return 1;
 }
 
-=item ActivityGet()
+=head2 ActivityGet()
 
 get Activity attributes
 
@@ -394,7 +388,7 @@ sub ActivityGet {
     return \%Data;
 }
 
-=item ActivityUpdate()
+=head2 ActivityUpdate()
 
 update Activity attributes
 
@@ -513,7 +507,7 @@ sub ActivityUpdate {
     return 1;
 }
 
-=item ActivityList()
+=head2 ActivityList()
 
 get an Activity list
 
@@ -535,6 +529,7 @@ get an Activity list
     $List = {
         'A1' => 'Activity1',
     }
+
 =cut
 
 sub ActivityList {
@@ -594,7 +589,7 @@ sub ActivityList {
     return \%Data;
 }
 
-=item ActivityListGet()
+=head2 ActivityListGet()
 
 get an Activity list with all activity details
 
@@ -688,9 +683,88 @@ sub ActivityListGet {
     return \@Data;
 }
 
-1;
+=head2 ActivitySearch()
 
-=back
+search activities by process name
+
+    my $ActivityEntityIDs = $ActivityObject->ActivitySearch(
+        ActivityName => 'SomeText',       # e. g. "SomeText*", "Some*ext" or ['*SomeTest1*', '*SomeTest2*']
+    );
+
+    Returns:
+
+    $ActivityEntityIDs = [ 'Activity-e11e2e9aa83344a235279d4f6babc6ec', 'Activity-f8194a25ab0ccddefeb4240c281c1f56' ];
+
+=cut
+
+sub ActivitySearch {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    if ( !$Param{ActivityName} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need ActivityName!',
+        );
+        return;
+    }
+
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    my $SQL = 'SELECT DISTINCT entity_id
+               FROM pm_activity ';
+
+    # if it's no ref, put it to array ref
+    if ( ref $Param{ActivityName} eq '' ) {
+        $Param{ActivityName} = [ $Param{ActivityName} ];
+    }
+
+    if ( IsArrayRefWithData( $Param{ActivityName} ) ) {
+        $SQL .= ' WHERE' if IsArrayRefWithData( $Param{ActivityName} );
+    }
+
+    my @QuotedSearch;
+    my $SQLOR = 0;
+
+    VALUE:
+    for my $Value ( @{ $Param{ActivityName} } ) {
+
+        next VALUE if !defined $Value || !length $Value;
+
+        $Value = '%' . $DBObject->Quote( $Value, 'Like' ) . '%';
+        $Value =~ s/\*/%/g;
+        $Value =~ s/%%/%/gi;
+
+        if ($SQLOR) {
+            $SQL .= ' OR';
+        }
+
+        $SQL .= ' name LIKE ? ';
+
+        push @QuotedSearch, $Value;
+        $SQLOR = 1;
+
+    }
+
+    if ( IsArrayRefWithData( $Param{ActivityName} ) ) {
+        $SQL .= $DBObject->GetDatabaseFunction('LikeEscapeString');
+    }
+    $SQL .= ' ORDER BY entity_id';
+
+    return if !$DBObject->Prepare(
+        SQL  => $SQL,
+        Bind => [ \(@QuotedSearch) ]
+    );
+
+    my @Data;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+        push @Data, $Row[0];
+    }
+
+    return \@Data;
+}
+
+1;
 
 =head1 TERMS AND CONDITIONS
 
