@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::UnitTest;
@@ -15,15 +15,11 @@ use File::stat;
 use Storable();
 use Term::ANSIColor();
 
-use Kernel::System::VariableCheck qw(IsArrayRefWithData);
-use Kernel::System::UnitTest::Driver;
-
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Encode',
     'Kernel::System::JSON',
     'Kernel::System::Main',
-    'Kernel::System::Package',
     'Kernel::System::SupportDataCollector',
     'Kernel::System::WebUserAgent',
 );
@@ -50,7 +46,7 @@ sub new {
     bless( $Self, $Type );
 
     $Self->{Debug} = $Param{Debug} || 0;
-    $Self->{ANSI}  = $Param{ANSI};
+    $Self->{ANSI} = $Param{ANSI};
 
     return $Self;
 }
@@ -72,7 +68,6 @@ run all or some tests located in C<scripts/test/**/*.t> and print the result.
                                                         #  You can specify %File%, %TestOk% and %TestNotOk% as dynamic arguments.
         PreSubmitScripts       => ['...'],              # Script(s) to execute after all tests have been executed
                                                         #  and the results are about to be sent to the server.
-        NumberOfTestRuns       => 10,                   # optional (default 1), number of successive runs for every single unit test
     );
 
 Please note that the individual test files are not executed in the main process,
@@ -108,11 +103,6 @@ sub Run {
         Recursive => 1,
     );
 
-    my $NumberOfTestRuns = $Param{NumberOfTestRuns};
-    if ( !$NumberOfTestRuns ) {
-        $NumberOfTestRuns = 1;
-    }
-
     FILE:
     for my $File (@Files) {
 
@@ -121,12 +111,10 @@ sub Run {
             next FILE;
         }
 
-        for ( 1 .. $NumberOfTestRuns ) {
-            $Self->_HandleFile(
-                PostTestScripts => $Param{PostTestScripts},
-                File            => $File,
-            );
-        }
+        $Self->_HandleFile(
+            PostTestScripts => $Param{PostTestScripts},
+            File            => $File,
+        );
     }
 
     # Use non-overridden time() function.
@@ -200,9 +188,12 @@ sub _HandleFile {
     # We're in the child process.
     if ( !$PID ) {
 
-        my $Driver = Kernel::System::UnitTest::Driver->new(
-            Verbose => $Self->{Verbose},
-            ANSI    => $Self->{ANSI},
+        my $Driver = $Kernel::OM->Create(
+            'Kernel::System::UnitTest::Driver',
+            ObjectParams => {
+                Verbose => $Self->{Verbose},
+                ANSI    => $Self->{ANSI},
+            },
         );
 
         $Driver->Run( File => $Param{File} );
@@ -213,10 +204,9 @@ sub _HandleFile {
     # Wait for child process to finish.
     waitpid( $PID, 0 );
 
-    my $ResultData = eval { Storable::retrieve($ResultDataFile) };
+    my $ResultData = Storable::retrieve($ResultDataFile);
 
     if ( !$ResultData ) {
-        print $Self->_Color( 'red', "Could not read result data for $Param{File}.\n" );
         $ResultData->{TestNotOk}++;
     }
 
@@ -248,44 +238,6 @@ sub _SubmitResults {
     my %SupportData = $Kernel::OM->Get('Kernel::System::SupportDataCollector')->Collect();
     die "Could not collect SupportData.\n" if !$SupportData{Success};
 
-    # Include versioning information as part of the support data.
-    #   Get framework commit ID from the RELEASE file.
-    my $ReleaseFile = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
-        Location => $Kernel::OM->Get('Kernel::Config')->Get('Home') . '/RELEASE',
-    );
-
-    if ( ${$ReleaseFile} =~ /COMMIT\_ID\s=\s(.*)$/ ) {
-        my $FrameworkCommitID = $1;
-        push @{ $SupportData{Result} },
-            {
-            Value       => $FrameworkCommitID,
-            Label       => 'Framework',
-            DisplayPath => 'Unit Test/Versioning Information',
-            Identifier  => 'VersionHash',
-            Status      => 1,
-            };
-    }
-
-    # Get build commit IDs of all installed packages.
-    my @PackageList = $Kernel::OM->Get('Kernel::System::Package')->RepositoryList(
-        Result => 'short',
-    );
-
-    if ( IsArrayRefWithData( \@PackageList ) ) {
-        for my $Package (@PackageList) {
-            if ( $Package->{BuildCommitID} ) {
-                push @{ $SupportData{Result} },
-                    {
-                    Value       => $Package->{BuildCommitID},
-                    Label       => $Package->{Name},
-                    DisplayPath => 'Unit Test/Versioning Information',
-                    Identifier  => 'VersionHash',
-                    Status      => 1,
-                    };
-            }
-        }
-    }
-
     my %SubmitData = (
         Auth     => $Param{SubmitAuth} // '',
         JobID    => $Param{JobID}      // '',
@@ -307,9 +259,9 @@ sub _SubmitResults {
     *STDOUT->flush();
     *STDERR->flush();
 
-    # Limit attachment sizes to 20MB in total.
-    my $AttachmentCount = scalar grep { -r $_ } @{ $Param{AttachmentPath} // [] };
-    my $AttachmentsSize = 1024 * 1024 * 20;
+    # Limit attachment sizes to 2MB in total.
+    my $AttachmentCount = scalar @{ $Param{AttachmentPath} // [] };
+    my $AttachmentsSize = 1024 * 1024 * 2;
 
     ATTACHMENT_PATH:
     for my $AttachmentPath ( @{ $Param{AttachmentPath} // [] } ) {
@@ -358,7 +310,6 @@ sub _SubmitResults {
                 Data => \%SubmitData,
             ),
         },
-        SkipSSLVerification => 1,
     );
 
     if ( $Response{Status} ne '200 OK' ) {
@@ -418,10 +369,10 @@ sub _Color {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
