@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::UnitTest::Selenium;
@@ -25,7 +25,7 @@ our @ObjectDependencies = (
     'Kernel::System::AuthSession',
     'Kernel::System::Log',
     'Kernel::System::Main',
-    'Kernel::System::Time',
+    'Kernel::System::DateTime',
     'Kernel::System::UnitTest::Driver',
     'Kernel::System::UnitTest::Helper',
 );
@@ -43,11 +43,7 @@ In case of an error, an exception will be thrown that you can catch in your
 unit test file and handle with C<HandleError()> in this class. It will output
 a failing test result and generate a screen shot for analysis.
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 create a selenium object to run front end tests.
 
@@ -111,34 +107,10 @@ sub new {
     $Kernel::OM->Get('Kernel::System::Main')->Require('Kernel::System::UnitTest::Selenium::WebElement')
         || die "Could not load Kernel::System::UnitTest::Selenium::WebElement";
 
-    my $Self;
-
-    # TEMPORARY WORKAROUND FOR GECKODRIVER BUG https://github.com/mozilla/geckodriver/issues/1470:
-    #   If marionette handshake fails, wait and try again. Can be removed after the bug is fixed
-    #   in a new geckodriver version.
-    eval {
-        $Self = $Class->SUPER::new(
-            webelement_class => 'Kernel::System::UnitTest::Selenium::WebElement',
-            error_handler    => \&SeleniumErrorHandler,
-            %SeleniumTestsConfig
-        );
-    };
-    if ($@) {
-        my $Exception = $@;
-
-        # Only handle this specific geckodriver exception.
-        die $Exception if $Exception !~ m{Socket timeout reading Marionette handshake data};
-
-        # Sleep and try again, bail out if it fails a second time.
-        #   A long sleep of 10 seconds is acceptable here, as it occurs only very rarely.
-        sleep 10;
-
-        $Self = $Class->SUPER::new(
-            webelement_class => 'Kernel::System::UnitTest::Selenium::WebElement',
-            %SeleniumTestsConfig
-        );
-    }
-
+    my $Self = $Class->SUPER::new(
+        webelement_class => 'Kernel::System::UnitTest::Selenium::WebElement',
+        %SeleniumTestsConfig
+    );
     $Self->{UnitTestDriverObject} = $Param{UnitTestDriverObject};
     $Self->{SeleniumTestsActive}  = 1;
 
@@ -154,55 +126,12 @@ sub new {
     $Self->{BaseURL} .= Kernel::System::UnitTest::Helper->GetTestHTTPHostname();
 
     # Remember the start system time for the selenium test run.
-    $Self->{TestStartSystemTime} = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    $Self->{TestStartSystemTime} = time;    ## no critic
 
-    # Force usage of legacy webdriver methods in Chrome until things are more stable.
-    if ( lc $SeleniumTestsConfig{browser_name} eq 'chrome' ) {
-        $Self->{is_wd3} = 0;
-    }
     return $Self;
 }
 
-sub SeleniumErrorHandler {
-    my ( $Self, $Error ) = @_;
-
-    my $Caller     = 0;
-    my $StackTrace = "Selenium stack trace: ($$): \n";
-
-    COUNT:
-    for ( my $Count = 0; $Count < 30; $Count++ ) {
-
-        my ( $Package1, $Filename1, $Line1, $Subroutine1 ) = caller( $Caller + $Count );
-
-        last COUNT if !$Line1;
-
-        my ( $Package2, $Filename2, $Line2, $Subroutine2 ) = caller( $Caller + 1 + $Count );
-
-        # if there is no caller module use the file name
-        $Subroutine2 ||= $0;
-
-        # print line if upper caller module exists
-        my $VersionString = '';
-
-        eval { $VersionString = $Package1->VERSION || ''; };    ## no critic
-
-        # version is present
-        if ($VersionString) {
-            $VersionString = ' (v' . $VersionString . ')';
-        }
-
-        $StackTrace .= "   Module: $Subroutine2$VersionString Line: $Line1\n";
-
-        last COUNT if !$Line2;
-    }
-
-    $Self->{_SeleniumStackTrace} = $StackTrace;
-    $Self->{_SeleniumException}  = $Error;
-
-    die $Error;
-}
-
-=item RunTest()
+=head2 RunTest()
 
 runs a selenium test if Selenium testing is configured and performs proper
 error handling (calls C<HandleError()> if needed).
@@ -227,13 +156,17 @@ sub RunTest {
     return 1;
 }
 
-=item _execute_command()
+=begin Internal:
+
+=head2 _execute_command()
 
 Override internal command of base class.
 
 We use it to output successful command runs to the UnitTest object.
 Errors will cause an exeption and be caught elsewhere.
 
+=end Internal:
+
 =cut
 
 sub _execute_command {    ## no critic
@@ -244,8 +177,8 @@ sub _execute_command {    ## no critic
     my $TestName = 'Selenium command success: ';
     $TestName .= $Kernel::OM->Get('Kernel::System::Main')->Dump(
         {
-            %{ $Res    || {} },
-            %{ $Params || {} },
+            %{ $Res    || {} },    ## no critic
+            %{ $Params || {} },    ## no critic
         }
     );
 
@@ -259,7 +192,7 @@ sub _execute_command {    ## no critic
     return $Result;
 }
 
-=item get()
+=head2 get()
 
 Override get method of base class to prepend the correct base URL.
 
@@ -281,7 +214,7 @@ sub get {    ## no critic
     return;
 }
 
-=item get_alert_text()
+=head2 get_alert_text()
 
 Override get_alert_text() method of base class to return alert text as string.
 
@@ -303,7 +236,7 @@ sub get_alert_text {    ## no critic
     return $AlertText;
 }
 
-=item VerifiedGet()
+=head2 VerifiedGet()
 
 perform a get() call, but wait for the page to be fully loaded (works only within OTRS).
 Will die() if the verification fails.
@@ -327,7 +260,7 @@ sub VerifiedGet {
     return;
 }
 
-=item VerifiedRefresh()
+=head2 VerifiedRefresh()
 
 perform a refresh() call, but wait for the page to be fully loaded (works only within OTRS).
 Will die() if the verification fails.
@@ -349,7 +282,7 @@ sub VerifiedRefresh {
     return;
 }
 
-=item Login()
+=head2 Login()
 
 login to agent or customer interface
 
@@ -432,15 +365,11 @@ wait with increasing sleep intervals until the given condition is true or the wa
 Exactly one condition (JavaScript or WindowCount) must be specified.
 
     my $Success = $SeleniumObject->WaitFor(
-        AlertPresent   => 1,                                 # Wait until an alert, confirm or prompt dialog is present
-        Callback       => sub { ... }                        # Wait until function returns true
-        ElementExists  => 'xpath-selector'                   # Wait until an element is present
-        ElementExists  => ['css-selector', 'css'],
-        ElementMissing => 'xpath-selector',                  # Wait until an element is not present
-        ElementMissing => ['css-selector', 'css'],
-        JavaScript     => 'return $(".someclass").length',   # Javascript code that checks condition
-        WindowCount    => 2,                                 # Wait until this many windows are open
-        Time           => 20,                                # optional, wait time in seconds (default 20)
+        JavaScript   => 'return $(".someclass").length',   # Javascript code that checks condition
+        AlertPresent => 1,                                 # Wait until an alert, confirm or prompt dialog is present
+        WindowCount  => 2,                                 # Wait until this many windows are open
+        Callback     => sub { ... }                        # Wait until function returns true
+        Time         => 20,                                # optional, wait time in seconds (default 20)
     );
 
 =cut
@@ -448,16 +377,8 @@ Exactly one condition (JavaScript or WindowCount) must be specified.
 sub WaitFor {
     my ( $Self, %Param ) = @_;
 
-    if (
-        !$Param{JavaScript}
-        && !$Param{WindowCount}
-        && !$Param{AlertPresent}
-        && !$Param{Callback}
-        && !$Param{ElementExists}
-        && !$Param{ElementMissing}
-        )
-    {
-        die "Need JavaScript, WindowCount, ElementExists, ElementMissing or AlertPresent.";
+    if ( !$Param{JavaScript} && !$Param{WindowCount} && !$Param{AlertPresent} && !$Param{Callback} ) {
+        die "Need JavaScript, WindowCount or AlertPresent.";
     }
 
     local $Self->{SuppressCommandRecording} = 1;
@@ -465,11 +386,10 @@ sub WaitFor {
     $Param{Time} //= 20;
     my $WaitedSeconds = 0;
     my $Interval      = 0.1;
-    my $WaitSeconds   = 0.5;
 
     while ( $WaitedSeconds <= $Param{Time} ) {
         if ( $Param{JavaScript} ) {
-            return 1 if $Self->execute_script( $Param{JavaScript} );
+            return 1 if $Self->execute_script( $Param{JavaScript} )
         }
         elsif ( $Param{WindowCount} ) {
             return 1 if scalar( @{ $Self->get_window_handles() } ) == $Param{WindowCount};
@@ -482,27 +402,9 @@ sub WaitFor {
         elsif ( $Param{Callback} ) {
             return 1 if $Param{Callback}->();
         }
-        elsif ( $Param{ElementExists} ) {
-            my @Arguments
-                = ref( $Param{ElementExists} ) eq 'ARRAY' ? @{ $Param{ElementExists} } : $Param{ElementExists};
-
-            if ( eval { $Self->find_element(@Arguments) } ) {
-                Time::HiRes::sleep($WaitSeconds);
-                return 1;
-            }
-        }
-        elsif ( $Param{ElementMissing} ) {
-            my @Arguments
-                = ref( $Param{ElementMissing} ) eq 'ARRAY' ? @{ $Param{ElementMissing} } : $Param{ElementMissing};
-
-            if ( !eval { $Self->find_element(@Arguments) } ) {
-                Time::HiRes::sleep($WaitSeconds);
-                return 1;
-            }
-        }
         Time::HiRes::sleep($Interval);
         $WaitedSeconds += $Interval;
-        $Interval      += 0.1;
+        $Interval += 0.1;
     }
 
     my $Argument = '';
@@ -514,41 +416,7 @@ sub WaitFor {
     die "WaitFor($Argument) failed.";
 }
 
-=item SwitchToFrame()
-
-Change focus to another frame on the page. If C<WaitForLoad> is passed, it will wait until the frame has loaded the
-page completely.
-
-    my $Success = $SeleniumObject->SwitchToFrame(
-        FrameSelector => '.Iframe',     # (required) CSS selector of the frame element
-        WaitForLoad   => 1,             # (optional) Wait until the frame has loaded, if necessary
-        Time          => 20,            # (optional) Wait time in seconds (default 20)
-    );
-
-=cut
-
-sub SwitchToFrame {
-    my ( $Self, %Param ) = @_;
-
-    if ( !$Param{FrameSelector} ) {
-        die 'Need FrameSelector.';
-    }
-
-    if ( $Param{WaitForLoad} ) {
-        $Self->WaitFor(
-            JavaScript => "return typeof(\$('$Param{FrameSelector}').get(0).contentWindow.Core) == 'object'
-                && typeof(\$('$Param{FrameSelector}').get(0).contentWindow.Core.App) == 'object'
-                && \$('$Param{FrameSelector}').get(0).contentWindow.Core.App.PageLoadComplete;",
-            Time => $Param{Time},
-        );
-    }
-
-    $Self->switch_to_frame( $Self->find_element( $Param{FrameSelector}, 'css' ) );
-
-    return 1;
-}
-
-=item DragAndDrop()
+=head2 DragAndDrop()
 
 Drag and drop an element.
 
@@ -612,7 +480,7 @@ sub DragAndDrop {
     return;
 }
 
-=item HandleError()
+=head2 HandleError()
 
 use this method to handle any Selenium exceptions.
 
@@ -626,13 +494,9 @@ for analysis (in folder /var/otrs-unittest if it exists, in $Home/var/httpd/htdo
 sub HandleError {
     my ( $Self, $Error ) = @_;
 
-    $Self->{UnitTestDriverObject}->False( 1, $Error );
-
-    # If we really have a selenium error, get the stack trace for it.
-    if ( $Error eq $Self->{_SeleniumException} && $Self->{_SeleniumStackTrace} ) {
-        $Self->{UnitTestDriverObject}->False( 1, $Self->{_SeleniumStackTrace} );
-    }
+    $Self->{UnitTestDriverObject}->False( 1, "Exception in Selenium': $Error" );
 
+    #eval {
     my $Data = $Self->screenshot();
     return if !$Data;
     $Data = MIME::Base64::decode_base64($Data);
@@ -643,7 +507,8 @@ sub HandleError {
     my $LocalScreenshotDir = $Kernel::OM->Get('Kernel::Config')->Get('Home') . '/var/httpd/htdocs/SeleniumScreenshots';
     mkdir $LocalScreenshotDir || return $Self->False( 1, "Could not create $LocalScreenshotDir." );
 
-    my $Filename = $Kernel::OM->Get('Kernel::System::Time')->CurrentTimestamp();
+    my $DateTimeObj = $Kernel::OM->Create('Kernel::System::DateTime');
+    my $Filename    = $DateTimeObj->ToString();
     $Filename .= '-' . ( int rand 100_000_000 ) . '.png';
     $Filename =~ s{[ :]}{-}smxg;
 
@@ -662,7 +527,7 @@ sub HandleError {
     #
     # If a shared screenshot folder is present, then we also store the screenshot there for external use.
     #
-    if ( -d '/var/otrs-unittest/' && -w '/var/otrs-unittest/' ) {
+    if ( -d '/var/otrs-unittest/' ) {
 
         my $SharedScreenshotDir = '/var/otrs-unittest/SeleniumScreenshots';
         mkdir $SharedScreenshotDir || return $Self->False( 1, "Could not create $SharedScreenshotDir." );
@@ -680,6 +545,8 @@ sub HandleError {
         Filename => $Filename,
         Content  => $Data
     );
+
+    return;
 }
 
 =head2 DEMOLISH()
@@ -729,63 +596,18 @@ sub DEMOLISH {
             $AuthSessionObject->RemoveSessionID( SessionID => $SessionID );
         }
     }
-}
 
-=head1 DEPRECATED FUNCTIONS
-
-=head2 InputFieldValueSet()
-
-sets modernized input field value.
-
-    $SeleniumObject->InputFieldValueSet(
-        Element => 'css-selector',              # (required) css selector
-        Value   => 3,                           # (optional) Value
-    );
-
-=cut
-
-sub InputFieldValueSet {
-    my ( $Self, %Param ) = @_;
-
-    # Check needed stuff.
-    if ( !$Param{Element} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Need Element!",
-        );
-        die 'Missing Element.';
-    }
-    my $Value = $Param{Value} // '';
-
-    if ( $Value !~ m{^\[} && $Value !~ m{^".*"$} ) {
-
-        # Quote text of Value is not array and if not already quoted.
-        $Value = "\"$Value\"";
-    }
-
-    # Set selected value.
-    $Self->execute_script(
-        "\$('$Param{Element}').val($Value).trigger('redraw.InputField').trigger('change');"
-    );
-
-    # Wait until selection tree is closed.
-    $Self->WaitFor(
-        ElementMissing => [ '.InputField_ListContainer', 'css' ],
-    );
-
-    return 1;
+    return;
 }
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
