@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Web::UploadCache::FS;
@@ -24,7 +24,7 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    $Self->{TempDir} = $Kernel::OM->Get('Kernel::Config')->Get('TempDir') . '/upload_cache/';
+    $Self->{TempDir} = $Kernel::OM->Get('Kernel::Config')->Get('TempDir') . '/upload_cache';
 
     if ( !-d $Self->{TempDir} ) {
         mkdir $Self->{TempDir};
@@ -36,9 +36,6 @@ sub new {
 sub FormIDCreate {
     my ( $Self, %Param ) = @_;
 
-    # cleanup temp form ids
-    $Self->FormIDCleanUp();
-
     # return requested form id
     return time() . '.' . rand(12341241);
 }
@@ -54,14 +51,18 @@ sub FormIDRemove {
         return;
     }
 
-    return if !$Self->_FormIDValidate( $Param{FormID} );
+    my $Directory = $Self->{TempDir} . '/' . $Param{FormID};
+
+    if ( !-d $Directory ) {
+        return 1;
+    }
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     my @List = $MainObject->DirectoryRead(
-        Directory => $Self->{TempDir},
-        Filter    => "$Param{FormID}.*",
+        Directory => $Directory,
+        Filter    => "*",
     );
 
     my @Data;
@@ -71,13 +72,20 @@ sub FormIDRemove {
         );
     }
 
+    if ( !rmdir($Directory) ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Can't remove: $Directory: $!!",
+        );
+    }
+
     return 1;
 }
 
 sub FormIDAddFile {
     my ( $Self, %Param ) = @_;
 
-    for (qw(FormID Filename Content ContentType)) {
+    for (qw(FormID Filename ContentType)) {
         if ( !$Param{$_} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
@@ -87,10 +95,10 @@ sub FormIDAddFile {
         }
     }
 
-    return if !$Self->_FormIDValidate( $Param{FormID} );
+    $Param{Content} = '' if !defined( $Param{Content} );
 
     # create content id
-    my $ContentID   = $Param{ContentID};
+    my $ContentID = $Param{ContentID};
     my $Disposition = $Param{Disposition} || '';
     if ( !$ContentID && lc $Disposition eq 'inline' ) {
 
@@ -100,34 +108,51 @@ sub FormIDAddFile {
         $ContentID = "$Disposition$Random.$Param{FormID}\@$FQDN";
     }
 
+    # create cache subdirectory if not exist
+    my $Directory = $Self->{TempDir} . '/' . $Param{FormID};
+    if ( !-d $Directory ) {
+
+        # Create directory. This could fail if another process creates the
+        #   same directory, so don't use the return value.
+        File::Path::mkpath( $Directory, 0, 0770 );    ## no critic
+
+        if ( !-d $Directory ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Can't create directory '$Directory': $!",
+            );
+            return;
+        }
+    }
+
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     # files must readable for creator
     return if !$MainObject->FileWrite(
-        Directory  => $Self->{TempDir},
-        Filename   => "$Param{FormID}.$Param{Filename}",
+        Directory  => $Directory,
+        Filename   => "$Param{Filename}",
         Content    => \$Param{Content},
         Mode       => 'binmode',
         Permission => '640',
     );
     return if !$MainObject->FileWrite(
-        Directory  => $Self->{TempDir},
-        Filename   => "$Param{FormID}.$Param{Filename}.ContentType",
+        Directory  => $Directory,
+        Filename   => "$Param{Filename}.ContentType",
         Content    => \$Param{ContentType},
         Mode       => 'binmode',
         Permission => '640',
     );
     return if !$MainObject->FileWrite(
-        Directory  => $Self->{TempDir},
-        Filename   => "$Param{FormID}.$Param{Filename}.ContentID",
+        Directory  => $Directory,
+        Filename   => "$Param{Filename}.ContentID",
         Content    => \$ContentID,
         Mode       => 'binmode',
         Permission => '640',
     );
     return if !$MainObject->FileWrite(
-        Directory  => $Self->{TempDir},
-        Filename   => "$Param{FormID}.$Param{Filename}.Disposition",
+        Directory  => $Directory,
+        Filename   => "$Param{Filename}.Disposition",
         Content    => \$Disposition,
         Mode       => 'binmode',
         Permission => '644',
@@ -148,8 +173,6 @@ sub FormIDRemoveFile {
         }
     }
 
-    return if !$Self->_FormIDValidate( $Param{FormID} );
-
     my @Index = @{ $Self->FormIDGetAllFilesMeta(%Param) };
 
     # finish if files have been already removed by other process
@@ -158,24 +181,30 @@ sub FormIDRemoveFile {
     my $ID   = $Param{FileID} - 1;
     my %File = %{ $Index[$ID] };
 
+    my $Directory = $Self->{TempDir} . '/' . $Param{FormID};
+
+    if ( !-d $Directory ) {
+        return 1;
+    }
+
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     $MainObject->FileDelete(
-        Directory => $Self->{TempDir},
-        Filename  => "$Param{FormID}.$File{Filename}",
+        Directory => $Directory,
+        Filename  => "$File{Filename}",
     );
     $MainObject->FileDelete(
-        Directory => $Self->{TempDir},
-        Filename  => "$Param{FormID}.$File{Filename}.ContentType",
+        Directory => $Directory,
+        Filename  => "$File{Filename}.ContentType",
     );
     $MainObject->FileDelete(
-        Directory => $Self->{TempDir},
-        Filename  => "$Param{FormID}.$File{Filename}.ContentID",
+        Directory => $Directory,
+        Filename  => "$File{Filename}.ContentID",
     );
     $MainObject->FileDelete(
-        Directory => $Self->{TempDir},
-        Filename  => "$Param{FormID}.$File{Filename}.Disposition",
+        Directory => $Directory,
+        Filename  => "$File{Filename}.Disposition",
     );
 
     return 1;
@@ -194,14 +223,18 @@ sub FormIDGetAllFilesData {
 
     my @Data;
 
-    return \@Data if !$Self->_FormIDValidate( $Param{FormID} );
+    my $Directory = $Self->{TempDir} . '/' . $Param{FormID};
+
+    if ( !-d $Directory ) {
+        return \@Data;
+    }
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     my @List = $MainObject->DirectoryRead(
-        Directory => $Self->{TempDir},
-        Filter    => "$Param{FormID}.*",
+        Directory => $Directory,
+        Filter    => "*",
     );
 
     my $Counter = 0;
@@ -218,37 +251,28 @@ sub FormIDGetAllFilesData {
         my $FileSize = -s $File;
 
         # human readable file size
-        if ($FileSize) {
+        if ( defined $FileSize ) {
 
             # remove meta data in files
             if ( $FileSize > 30 ) {
-                $FileSize = $FileSize - 30;
-            }
-            if ( $FileSize > 1048576 ) {    # 1024 * 1024
-                $FileSize = sprintf "%.1f MBytes", ( $FileSize / 1048576 );    # 1024 * 1024
-            }
-            elsif ( $FileSize > 1024 ) {
-                $FileSize = sprintf "%.1f KBytes", ( ( $FileSize / 1024 ) );
-            }
-            else {
-                $FileSize = $FileSize . ' Bytes';
+                $FileSize = $FileSize - 30
             }
         }
         my $Content = $MainObject->FileRead(
             Location => $File,
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',    # optional - binmode|utf8
         );
         next FILE if !$Content;
 
         my $ContentType = $MainObject->FileRead(
             Location => "$File.ContentType",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
         next FILE if !$ContentType;
 
         my $ContentID = $MainObject->FileRead(
             Location => "$File.ContentID",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
         next FILE if !$ContentID;
 
@@ -259,11 +283,12 @@ sub FormIDGetAllFilesData {
 
         my $Disposition = $MainObject->FileRead(
             Location => "$File.Disposition",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
+        next FILE if !$Disposition;
 
         # strip filename
-        $File =~ s/^.*\/$Param{FormID}\.(.+?)$/$1/;
+        $File =~ s/^.*\/(.+?)$/$1/;
         push(
             @Data,
             {
@@ -294,14 +319,18 @@ sub FormIDGetAllFilesMeta {
 
     my @Data;
 
-    return \@Data if !$Self->_FormIDValidate( $Param{FormID} );
+    my $Directory = $Self->{TempDir} . '/' . $Param{FormID};
+
+    if ( !-d $Directory ) {
+        return \@Data;
+    }
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     my @List = $MainObject->DirectoryRead(
-        Directory => $Self->{TempDir},
-        Filter    => "$Param{FormID}.*",
+        Directory => $Directory,
+        Filter    => "*",
     );
 
     my $Counter = 0;
@@ -318,32 +347,23 @@ sub FormIDGetAllFilesMeta {
         my $FileSize = -s $File;
 
         # human readable file size
-        if ($FileSize) {
+        if ( defined $FileSize ) {
 
             # remove meta data in files
             if ( $FileSize > 30 ) {
-                $FileSize = $FileSize - 30;
-            }
-            if ( $FileSize > 1048576 ) {    # 1024 * 1024
-                $FileSize = sprintf "%.1f MBytes", ( $FileSize / 1048576 );    # 1024 * 1024
-            }
-            elsif ( $FileSize > 1024 ) {
-                $FileSize = sprintf "%.1f KBytes", ( ( $FileSize / 1024 ) );
-            }
-            else {
-                $FileSize = $FileSize . ' Bytes';
+                $FileSize = $FileSize - 30
             }
         }
 
         my $ContentType = $MainObject->FileRead(
             Location => "$File.ContentType",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
         next FILE if !$ContentType;
 
         my $ContentID = $MainObject->FileRead(
             Location => "$File.ContentID",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
         next FILE if !$ContentID;
 
@@ -354,11 +374,12 @@ sub FormIDGetAllFilesMeta {
 
         my $Disposition = $MainObject->FileRead(
             Location => "$File.Disposition",
-            Mode     => 'binmode',                                             # optional - binmode|utf8
+            Mode     => 'binmode',             # optional - binmode|utf8
         );
+        next FILE if !$Disposition;
 
         # strip filename
-        $File =~ s/^.*\/$Param{FormID}\.(.+?)$/$1/;
+        $File =~ s/^.*\/(.+?)$/$1/;
         push(
             @Data,
             {
@@ -377,44 +398,53 @@ sub FormIDGetAllFilesMeta {
 sub FormIDCleanUp {
     my ( $Self, %Param ) = @_;
 
-    my $CurrentTile = time() - 86400;                                            # 60 * 60 * 24 * 1
-    my @List        = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+    my $RetentionTime = int( time() - 86400 );        # remove subdirs older than 24h
+    my @List          = $MainObject->DirectoryRead(
         Directory => $Self->{TempDir},
         Filter    => '*'
     );
 
-    my %RemoveFormIDs;
-    for my $File (@List) {
+    SUBDIR:
+    for my $Subdir (@List) {
+        my $SubdirTime = $Subdir;
 
-        # get FormID
-        $File =~ s/^.*\/(.+?)\..+?$/$1/;
-        if ( $CurrentTile > $File ) {
-            if ( !$RemoveFormIDs{$File} ) {
-                $RemoveFormIDs{$File} = 1;
+        if ( $SubdirTime =~ /^.*\/\d+\..+$/ ) {
+            $SubdirTime =~ s/^.*\/(\d+?)\..+$/$1/
+        }
+        else {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message =>
+                    "Won't delete upload cache directory $Subdir: timestamp in directory name not found! Please fix it manually.",
+            );
+            next SUBDIR;
+        }
+
+        if ( $RetentionTime > $SubdirTime ) {
+            my @Sublist = $MainObject->DirectoryRead(
+                Directory => $Subdir,
+                Filter    => "*",
+            );
+
+            for my $File (@Sublist) {
+                $MainObject->FileDelete(
+                    Location => $File,
+                );
+            }
+
+            if ( !rmdir($Subdir) ) {
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'error',
+                    Message  => "Can't remove: $Subdir: $!!",
+                );
+                return;
             }
         }
     }
 
-    for ( sort keys %RemoveFormIDs ) {
-        $Self->FormIDRemove( FormID => $_ );
-    }
-
-    return 1;
-}
-
-sub _FormIDValidate {
-    my ( $Self, $FormID ) = @_;
-
-    return if !$FormID;
-
-    if ( $FormID !~ m{^ \d+ \. \d+ \. \d+ $}xms ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Invalid FormID!',
-        );
-        return;
-    }
-
     return 1;
 }
 
