@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -265,9 +265,10 @@ Core.Form.Validate = (function (TargetNS) {
 
         // for richtextareas, get editor code and remove all tags and whitespace
         // keep tags if images are embedded because of inline-images
+        // keep tags if codemirror plugin is used (for XSLT editor)
         if (Core.UI.RichTextEditor.IsEnabled($Element)) {
             Value = CKEDITOR.instances[Element.id].getData();
-            if (!Value.match(/<img/)) {
+            if (typeof CKEDITOR.instances[Element.id].config.codemirror === 'undefined' && !Value.match(/<img/)) {
                 Value = Value.replace(/\s+|&nbsp;|<\/?\w+[^>]*\/?>/g, '');
             }
         }
@@ -280,17 +281,49 @@ Core.Form.Validate = (function (TargetNS) {
         return $.trim(Value).length > 0;
     }
 
+    /**
+     * @private
+     * @name ValidatorMethodDnDUpload
+     * @memberof Core.Form.Validate
+     * @function
+     * @returns {Boolean} True if a DnDUpload field has at least one uploaded attachment, false otherwise
+     * @param {String} Value
+     * @param {DOMObject} Element
+     * @description
+     *      Validator method for checking if a value is present for
+     *      different types of elements.
+     */
+    function ValidatorMethodDnDUpload(Value, Element) {
+
+        var $AttachmentList = $(Element).prev('.AttachmentListContainer'),
+            AttachmentCount = $AttachmentList.find('table tbody tr').length;
+
+        return AttachmentCount;
+    }
+
     /*
      * Definitions of all OTRS specific rules and rule methods
      */
     $.validator.addMethod("Validate_Required", ValidatorMethodRequired, "");
     $.validator.addMethod("Validate_Number", $.validator.methods.digits, "");
+    $.validator.addMethod("Validate_DnDUpload", ValidatorMethodDnDUpload, "");
 
     // There is a configuration option in OTRS that controls if email addresses
     // should be validated or not.
     // If email address should be validated, this function is overwritten in Init method
     $.validator.addMethod("Validate_Email", ValidatorMethodRequired, "");
 
+
+    // Validates e-mail address in a field, but does not return an error if field is empty
+    $.validator.addMethod("Validate_Email_Optional", function (Value, Element) {
+        if (!Value.length) {
+            return true;
+        }
+        else {
+            return $.validator.methods.email.call(this, Value, Element);
+        }
+    }, "");
+
     // Use the maxlength attribute to have a dynamic validation
     // Textarea fields will need JS code to set the maxlength attribute since is not supported by
     // XHTML
@@ -321,6 +354,10 @@ Core.Form.Validate = (function (TargetNS) {
      * @param {Object} [DateOptions]
      * @param {Boolean} [DateOptions.DateInFuture]
      * @param {Boolean} [DateOptions.DateNotInFuture]
+     * @param {String} [DateOptions.DateAfterPrefix] - Check if the value is after the supplied field prefix
+     * @param {String} [DateOptions.DateAfterValue] - Check if the value is after the supplied date
+     * @param {String} [DateOptions.DateBeforePrefix] - Check if the value is before the supplied field prefix
+     * @param {String} [DateOptions.DateBeforeValue] - Check if the value is before the supplied date
      * @description
      *      Validator method for dates.
      */
@@ -339,6 +376,7 @@ Core.Form.Validate = (function (TargetNS) {
         DateMonthClassPrefix = 'Validate_DateMonth_',
         DateHourClassPrefix = 'Validate_DateHour_',
         DateMinuteClassPrefix = 'Validate_DateMinute_',
+        DateAfterBefore,
         DateCheck,
         $UsedObj;
 
@@ -366,6 +404,7 @@ Core.Form.Validate = (function (TargetNS) {
                 MinuteElement = ClassValue.replace(DateMinuteClassPrefix, '');
             }
         });
+
         if (YearElement.length && MonthElement.length && $('#' + Core.App.EscapeSelector(YearElement)).length && $('#' + Core.App.EscapeSelector(MonthElement)).length) {
             DateObject = new Date($('#' + Core.App.EscapeSelector(YearElement)).val(), $('#' + Core.App.EscapeSelector(MonthElement)).val() - 1, Value);
             if (DateObject.getFullYear() === parseInt($('#' + Core.App.EscapeSelector(YearElement)).val(), 10) &&
@@ -390,6 +429,57 @@ Core.Form.Validate = (function (TargetNS) {
                         return true;
                     }
                 }
+                else if (
+                    DateOptions.DateAfterPrefix || DateOptions.DateBeforePrefix
+                    || DateOptions.DateAfterValue || DateOptions.DateBeforeValue
+                    )
+                {
+                    DateAfterBefore = DateOptions.DateAfterPrefix || DateOptions.DateBeforePrefix
+                        || DateOptions.DateAfterValue || DateOptions.DateBeforeValue;
+
+                    if (DateOptions.DateAfterPrefix || DateOptions.DateBeforePrefix) {
+                        DateAfterBefore = Core.App.EscapeSelector(DateAfterBefore);
+                        if (
+                            $('#' + DateAfterBefore + 'Year').length &&
+                            $('#' + DateAfterBefore + 'Month').length &&
+                            $('#' + DateAfterBefore + 'Day').length
+                            )
+                        {
+                            DateCheck = new Date(
+                                $('#' + DateAfterBefore + 'Year').val(),
+                                $('#' + DateAfterBefore + 'Month').val() - 1,
+                                $('#' + DateAfterBefore + 'Day').val()
+                            );
+                            if (
+                                $('#' + DateAfterBefore + 'Hour').length &&
+                                $('#' + DateAfterBefore + 'Minute').length
+                                )
+                            {
+                                DateCheck.setHours(
+                                    $('#' + DateAfterBefore + 'Hour').val(),
+                                    $('#' + DateAfterBefore + 'Minute').val(),
+                                    0,
+                                    0
+                                );
+                            }
+                            else {
+                                DateCheck.setHours(0, 0, 0, 0);
+                            }
+                        }
+                    } else {
+                        DateCheck = new Date(DateAfterBefore);
+                    }
+
+                    if (DateOptions.DateAfterPrefix || DateOptions.DateAfterValue) {
+                        if (DateObject >= DateCheck) {
+                            return true;
+                        }
+                    } else if (DateOptions.DateBeforePrefix || DateOptions.DateBeforeValue) {
+                        if (DateObject <= DateCheck) {
+                            return true;
+                        }
+                    }
+                }
                 else {
                     return true;
                 }
@@ -424,6 +514,40 @@ Core.Form.Validate = (function (TargetNS) {
         return DateValidator(Value, Element, { DateNotInFuture: true });
     }, "");
 
+    $.validator.addMethod("Validate_DateAfter", function (Value, Element) {
+        var $DateSelection = $(Element).parent().find('input[type=checkbox].DateSelection');
+        // do not do this check for unchecked date/datetime fields
+        // check first if the field exists to regard the check for the pending reminder field
+        if ($DateSelection.length && !$DateSelection.prop("checked")) {
+            return true;
+        }
+        if ($(Element).data('validate-date-after')) {
+            return DateValidator(Value, Element, { DateAfterValue: $(Element).data('validate-date-after') });
+        }
+        return DateValidator(Value, Element, {
+            DateAfterPrefix: $.grep(Element.className.split(" "), function(ClassName){
+                return ClassName.indexOf('Validate_DateAfter_') === 0;
+            }).join().substring(19)
+        });
+    }, "");
+
+    $.validator.addMethod("Validate_DateBefore", function (Value, Element) {
+        var $DateSelection = $(Element).parent().find('input[type=checkbox].DateSelection');
+        // do not do this check for unchecked date/datetime fields
+        // check first if the field exists to regard the check for the pending reminder field
+        if ($DateSelection.length && !$DateSelection.prop("checked")) {
+            return true;
+        }
+        if ($(Element).data('validate-date-before')) {
+            return DateValidator(Value, Element, { DateBeforeValue: $(Element).data('validate-date-before') });
+        }
+        return DateValidator(Value, Element, {
+            DateBeforePrefix: $.grep(Element.className.split(" "), function(ClassName){
+                return ClassName.indexOf('Validate_DateBefore_') === 0;
+            }).join().substring(20)
+        });
+    }, "");
+
     $.validator.addMethod("Validate_DateHour", function (Value) {
         return (parseInt(Value, 10) >= 0 && parseInt(Value, 10) < 24);
     }, "");
@@ -496,6 +620,10 @@ Core.Form.Validate = (function (TargetNS) {
         Validate_Required: true
     });
 
+    $.validator.addClassRules("Validate_DnDUpload", {
+        Validate_DnDUpload: true
+    });
+
     $.validator.addClassRules("Validate_Number", {
         Validate_Number: true
     });
@@ -504,6 +632,10 @@ Core.Form.Validate = (function (TargetNS) {
         Validate_Email: true
     });
 
+    $.validator.addClassRules("Validate_Email_Optional", {
+        Validate_Email_Optional: true
+    });
+
     $.validator.addClassRules("Validate_MaxLength", {
         Validate_MaxLength: true
     });
@@ -629,6 +761,29 @@ Core.Form.Validate = (function (TargetNS) {
         /*eslint-enable camelcase */
     });
 
+    $.validator.addMethod("Validate_Regex", ValidatorMethodRegex, "");
+
+    /**
+     * @private
+     * @name ValidatorMethodRegex
+     * @memberof Core.Form.Validate
+     * @function
+     * @returns {Boolean} True, if Value has a length, false otherwise.
+     * @param {String} Value
+     * @param {DOMObject} Element
+     * @description
+     *      Validator method for checking if a value satisfies regex expression.
+     */
+    function ValidatorMethodRegex(Value, Element) {
+        var Regex = $(Element).attr("data-regex");
+
+        if (Value.match(Regex)) {
+            return true;
+        }
+
+        return false;
+    }
+
     /**
      * @name Init
      * @memberof Core.Form.Validate
@@ -650,7 +805,7 @@ Core.Form.Validate = (function (TargetNS) {
 
         // There is a configuration option in OTRS that controls if email addresses
         //  should be validated or not.
-        if (Core.Config.Get('CheckEmailAddresses')) {
+        if (parseInt(Core.Config.Get('CheckEmailAddresses'), 10)) {
             $.validator.addMethod("Validate_Email", $.validator.methods.email, "");
         }
 
@@ -691,7 +846,7 @@ Core.Form.Validate = (function (TargetNS) {
                 $ServerErrors.eq(0).focus();
             };
 
-            Core.UI.Dialog.ShowAlert(Core.Config.Get('ValidateServerErrorTitle'), Core.Config.Get('ValidateServerErrorMsg'), ServerErrorDialogCloseFunction);
+            Core.UI.Dialog.ShowAlert(Core.Language.Translate('Error'), Core.Language.Translate('One or more errors occurred!'), ServerErrorDialogCloseFunction);
         }
     };
 
@@ -817,5 +972,7 @@ Core.Form.Validate = (function (TargetNS) {
             .removeClass(Options.IgnoreClass);
     };
 
+    Core.Init.RegisterNamespace(TargetNS, 'APP_GLOBAL');
+
     return TargetNS;
 }(Core.Form.Validate || {}));
