@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -57,24 +57,7 @@ Core.UI.RichTextEditor = (function (TargetNS) {
     }
 
     /**
-     * @private
-     * @name SerializeData
-     * @memberof Core.UI.RichTextEditor
-     * @function
-     * @return {string} query string of the data
-     * @param {Object} Data The data that should be converted
-     * @description Converts a given hash into a query string
-     */
-    function SerializeData(Data) {
-        var QueryString = '';
-        $.each(Data, function (Key, Value) {
-            QueryString += ';' + encodeURIComponent(Key) + '=' + encodeURIComponent(Value);
-        });
-        return QueryString;
-    }
-
-    /**
-     * @name Init
+     * @name InitEditor
      * @memberof Core.UI.RichTextEditor
      * @function
      * @returns {Boolean} Returns false on error.
@@ -82,11 +65,16 @@ Core.UI.RichTextEditor = (function (TargetNS) {
      * @description
      *      This function initializes the application and executes the needed functions.
      */
-    TargetNS.Init = function ($EditorArea) {
+    TargetNS.InitEditor = function ($EditorArea) {
         var EditorID = '',
             Editor,
             UserLanguage,
-            UploadURL = '';
+            UploadURL = '',
+            EditorConfig;
+
+        if (typeof CKEDITOR === 'undefined') {
+            return false;
+        }
 
         if (isJQueryObject($EditorArea) && $EditorArea.hasClass('HasCKEInstance')) {
             return false;
@@ -111,22 +99,38 @@ Core.UI.RichTextEditor = (function (TargetNS) {
                 window.clearTimeout(TimeOutRTEOnChange);
                 TimeOutRTEOnChange = window.setTimeout(function () {
                     Core.Form.Validate.ValidateElement($(Editor.editor.element.$));
+                    Core.App.Publish('Event.UI.RichTextEditor.ChangeValidationComplete', [Editor]);
                 }, 250);
             });
 
-            // if spell checker is used on paste new content should spell check again
-            Editor.editor.on('paste', function() {
-                Core.Config.Set('TextIsSpellChecked', false);
-            });
-            // if spell checker is used on any key new content should spell check again
-            Editor.editor.on('key', function() {
-                Core.Config.Set('TextIsSpellChecked', false);
-            });
-
             Core.App.Publish('Event.UI.RichTextEditor.InstanceCreated', [Editor]);
         });
 
         CKEDITOR.on('instanceReady', function (Editor) {
+
+            // specific config for CodeMirror instances (e.g. XSLT editor)
+            if (Core.Config.Get('RichText.Type') == 'CodeMirror') {
+
+                // The width of a tab character. Defaults to 4.
+                window[ 'codemirror_' + Editor.editor.id ].setOption("tabSize", 4);
+
+                // How many spaces a block (whatever that means in the edited language) should be indented. The default is 2.
+                window[ 'codemirror_' + Editor.editor.id ].setOption("indentUnit", 4);
+
+                // Whether to use the context-sensitive indentation that the mode provides (or just indent the same as the line before). Defaults to true.
+                window[ 'codemirror_' + Editor.editor.id ].setOption("tabMode", 'spaces');
+                window[ 'codemirror_' + Editor.editor.id ].setOption("smartIndent", true);
+
+                // convert tabs to spaces
+                window[ 'codemirror_' + Editor.editor.id ].setOption("extraKeys", {
+                    Tab: function(cm) {
+                        var spaces = Array(cm.getOption("indentUnit") + 1).join(" ");
+                        cm.replaceSelection(spaces);
+                    }
+                });
+
+            }
+
             Core.App.Publish('Event.UI.RichTextEditor.InstanceReady', [Editor]);
         });
 
@@ -136,18 +140,21 @@ Core.UI.RichTextEditor = (function (TargetNS) {
 
         // build URL for image upload
         if (CheckFormID($EditorArea).length) {
+
             UploadURL = Core.Config.Get('Baselink')
                     + 'Action='
                     + Core.Config.Get('RichText.PictureUploadAction', 'PictureUpload')
                     + '&FormID='
                     + CheckFormID($EditorArea).val()
-                    + SerializeData(Core.App.GetSessionInformation());
+                    + '&' + Core.Config.Get('SessionName')
+                    + '=' + Core.Config.Get('SessionID');
         }
 
+        // set default editor config, but allow custom config for other types for editors
         /*eslint-disable camelcase */
-        Editor = CKEDITOR.replace(EditorID,
-        {
+        EditorConfig = {
             customConfig: '', // avoid loading external config files
+            disableNativeSpellChecker: false,
             defaultLanguage: UserLanguage,
             language: UserLanguage,
             width: Core.Config.Get('RichText.Width', 620),
@@ -161,21 +168,52 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             enterMode: CKEDITOR.ENTER_BR,
             shiftEnterMode: CKEDITOR.ENTER_BR,
             contentsLangDirection: Core.Config.Get('RichText.TextDir', 'ltr'),
-            disableNativeSpellChecker: false,
             toolbar: CheckFormID($EditorArea).length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
             filebrowserBrowseUrl: '',
             filebrowserUploadUrl: UploadURL,
-            extraPlugins: Core.Config.Get('RichText.SpellChecker') ? 'aspell,splitquote,contextmenu_linkopen,preventimagepaste' : 'splitquote,contextmenu_linkopen,preventimagepaste',
+            extraPlugins: 'splitquote,preventimagepaste',
             entities: false,
-            skin: 'bootstrapck'
-        });
+            skin: 'moono-lisa'
+        };
         /*eslint-enable camelcase */
 
-        CKEDITOR.config.spellerPagesServerScript = Core.Config.Get('Baselink');
+        // specific config for CodeMirror instances (e.g. XSLT editor)
+        if (Core.Config.Get('RichText.Type') == 'CodeMirror') {
+            $.extend(EditorConfig, {
+
+                /*eslint-disable camelcase */
+                startupMode: 'source',
+                allowedContent: true,
+                extraPlugins: 'codemirror',
+                codemirror: {
+                    theme: 'default',
+                    lineNumbers: true,
+                    lineWrapping: true,
+                    matchBrackets: true,
+                    autoCloseTags: true,
+                    autoCloseBrackets: true,
+                    enableSearchTools: true,
+                    enableCodeFolding: true,
+                    enableCodeFormatting: true,
+                    autoFormatOnStart: false,
+                    autoFormatOnModeChange: false,
+                    autoFormatOnUncomment: false,
+                    mode: 'htmlmixed',
+                    showTrailingSpace: true,
+                    highlightMatches: true,
+                    styleActiveLine: true
+                }
+                /*eslint-disable camelcase */
+
+            });
+        }
+
+        Editor = CKEDITOR.replace(EditorID, EditorConfig);
 
         // check if creating CKEditor was successful
         // might be a problem on mobile devices e.g.
         if (typeof Editor !== 'undefined') {
+
             // Hack for updating the textarea with the RTE content (bug#5857)
             // Rename the original function to another name, than overwrite the original one
             CKEDITOR.instances[EditorID].updateElementOriginal = CKEDITOR.instances[EditorID].updateElement;
@@ -191,9 +229,12 @@ Core.UI.RichTextEditor = (function (TargetNS) {
                 //  like '<br/>' stored in the DB.
                 Data = this.element.getValue(); // get textarea content
 
-                // only if data contains no image tag,
+                // only if codemirror plugin is not used (for XSLT editor)
+                // or
+                // if data contains no image tag,
                 // this is important for inline images, we don't want to remove them!
-                if (!Data.match(/<img/)) {
+                if (typeof CKEDITOR.instances[EditorID].config.codemirror === 'undefined' && !Data.match(/<img/)) {
+
                     // remove tags and whitespace for checking
                     Data = Data.replace(/\s+|&nbsp;|<\/?\w+[^>]*\/?>/g, '');
                     if (!Data.length) {
@@ -202,6 +243,23 @@ Core.UI.RichTextEditor = (function (TargetNS) {
                 }
             };
 
+            // Redefine 'writeCssText' function because of unnecessary sorting of CSS properties (bug#12848).
+            /* eslint-disable no-unused-vars */
+            CKEDITOR.tools.writeCssText = function (styles, sort) {
+                var name,
+                stylesArr = [];
+
+                for (name in styles)
+                    stylesArr.push(name + ':' + styles[name]);
+
+                // This block sorts CSS properties which can make a wrong CSS style sent to CKEditor.
+                // if ( sort )
+                //     stylesArr.sort();
+
+                return stylesArr.join('; ');
+            };
+            /* eslint-enable no-unused-vars */
+
             // Needed for clientside validation of RTE
             CKEDITOR.instances[EditorID].on('blur', function () {
                 CKEDITOR.instances[EditorID].updateElement();
@@ -217,6 +275,7 @@ Core.UI.RichTextEditor = (function (TargetNS) {
                     window.setTimeout(function () {
                         CKEDITOR.instances[EditorID].updateElement();
                         Core.Form.Validate.ValidateElement($EditorArea);
+                        Core.App.Publish('Event.UI.RichTextEditor.FocusValidationComplete', [Editor]);
                     }, 0);
                 }
             });
@@ -230,18 +289,37 @@ Core.UI.RichTextEditor = (function (TargetNS) {
     };
 
     /**
-     * @name InitAll
+     * @name InitAllEditors
      * @memberof Core.UI.RichTextEditor
      * @function
      * @description
      *      This function initializes as a rich text editor every textarea element that containing the RichText class.
      */
-    TargetNS.InitAll = function () {
+    TargetNS.InitAllEditors = function () {
+        if (typeof CKEDITOR === 'undefined') {
+            return;
+        }
+
         $('textarea.RichText').each(function () {
-            TargetNS.Init($(this));
+            TargetNS.InitEditor($(this));
         });
     };
 
+    /**
+     * @name Init
+     * @memberof Core.UI.RichTextEditor
+     * @function
+     * @description
+     *      This function initializes JS functionality.
+     */
+    TargetNS.Init = function () {
+        if (typeof CKEDITOR === 'undefined') {
+            return;
+        }
+
+        TargetNS.InitAllEditors();
+    };
+
     /**
      * @name GetRTE
      * @memberof Core.UI.RichTextEditor
@@ -339,5 +417,7 @@ Core.UI.RichTextEditor = (function (TargetNS) {
         }
     };
 
+    Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
+
     return TargetNS;
 }(Core.UI.RichTextEditor || {}));
